Run in command prompt: "python setup.py bdist_wheel" to build the library
Run in command prompt: "python setup.py sdist" to build the tar file for PyPi
Run in command prompt: "twine upload dist/*" to send the package to PyPi